package argumentrelevance.argumentranker;

import java.util.List;

import argumentrelevance.storage.ArgumentUnit;

/**
 * This class represents the approach that ranks arguments according to the 
 * average PageRank value of the argument's premises.
 * 
 * @author henning.wachsmuth
 *
 */
public class PageRankAvgRanker extends AbstractPremiseBasedRanker {

	@Override
	public double computePremiseBasedScore(List<ArgumentUnit> premises) {
		double avgPremisePageRank = 0.0;
		for (ArgumentUnit premise : premises) {
			avgPremisePageRank += premise.getPageRank()/premise.getFrequency();
		}
		if (Double.compare(avgPremisePageRank, 0.0) == 0){
			return 0.0;
		}
		return avgPremisePageRank / premises.size();
	}

}
