package argumentrelevance.argumentranker;

import java.util.List;

import argumentrelevance.storage.ArgumentUnit;

/**
 * This class represents the approach that ranks arguments according to the 
 * maximum PageRank value of the argument's premises.
 * 
 * @author henning.wachsmuth
 *
 */
public class PageRankMaxRanker extends AbstractPremiseBasedRanker {

	@Override
	public double computePremiseBasedScore(List<ArgumentUnit> premises) {
		double maxPremisePageRank = 0.0;
		for (ArgumentUnit premise : premises) {
			if (premise.getPageRank()/premise.getFrequency() 
					> maxPremisePageRank){
				maxPremisePageRank = 
						premise.getPageRank()/premise.getFrequency();
			}
		}
		return maxPremisePageRank;
	}

}
