package argumentrelevance.argumentranker;

import java.util.List;

import argumentrelevance.storage.ArgumentUnit;

/**
 * This class represents the approach that ranks arguments according to the 
 * minimum PageRank value of the argument's premises.
 * 
 * @author henning.wachsmuth
 *
 */
public class PageRankMinRanker extends AbstractPremiseBasedRanker {

	@Override
	public double computePremiseBasedScore(List<ArgumentUnit> premises) {
		double minPremisePageRank = 1.1;
		for (ArgumentUnit premise : premises) {
			if (premise.getPageRank()/premise.getFrequency() 
					< minPremisePageRank){
				minPremisePageRank = 
						premise.getPageRank()/premise.getFrequency();
			}
		}
		if (Double.compare(minPremisePageRank, 1.1) == 0){
			return 0.0;
		}
		return minPremisePageRank;
	}

}
