package argumentrelevance.argumentranker;

import java.util.List;
import java.util.Map;
import java.util.Random;
import java.util.TreeMap;

import argumentrelevance.storage.Argument;
import argumentrelevance.storage.ArgumentRanking;
import argumentrelevance.storage.ArgumentUnit;

/**
 * This class represents the approach that ranks arguments pseudorandomly.
 * 
 * @author henning.wachsmuth
 *
 */
public class RandomRanker extends AbstractRanker {

	/**
	 * Random score generator
	 */
	private static final Random RANDOM = new Random(-1);
	
	@Override
	public ArgumentRanking computeArgumentScores(ArgumentUnit conclusion,
			List<Argument> arguments,
			Map<Integer, ArgumentUnit> allArgumentUnits,
			Map<Integer, Argument> allArguments) {
		// Compute and return one random score for each argument
		TreeMap<Integer, Double> argID2Score = new TreeMap<Integer, Double>();
		for (Argument argument : arguments) {
			argID2Score.put(argument.getArgumentID(), RANDOM.nextDouble());
		}		
		return new ArgumentRanking(conclusion.getArgumentUnitID(), argID2Score);	
	}

}
