package argumentrelevance.rankingcorrelation;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * This class computes the Kendall's tau rank correlations between argument 
 * rankings.
 * 
 * @author henning.wachsmuth
 *
 */
public class KendallCorrelationComputer extends AbstractCorrelationComputer {

	/**
	 * Parameter for what tau to use
	 */
	public static String TAU = 
//			"tau-a"; 
			"tau-b";
	
	@Override
	public double computeCorrelation(Map<Integer, Double> argumentID2RankA,
			Map<Integer, Double> argumentID2RankB) {
		// Create rank pairs
		List<double[]> rankPairs = new ArrayList<double[]>();
		for (int argumentID : argumentID2RankA.keySet()) {
			double [] rankPair = {argumentID2RankA.get(argumentID), 
					argumentID2RankB.get(argumentID)};
			rankPairs.add(rankPair);
		}
		// Compute concordances
		double concordantPairs = 0.0;
		double disconcordantPairs = 0.0; 
		double tiesA = 0.0;
		double tiesB = 0.0;
		for (int i=0; i<rankPairs.size(); i++) {
			for (int j=i+1; j<rankPairs.size(); j++) {
				double [] pair1 = rankPairs.get(i);
				double [] pair2 = rankPairs.get(j);
				// Check if concordant
				if ((pair1[0] < pair2[0] && pair1[1] < pair2[1])
						|| (pair1[0] > pair2[0] && pair1[1] > pair2[1])){
					concordantPairs += 1.0;
				}
				// Check if disconcordant
				else if ((pair1[0] < pair2[0] && pair1[1] > pair2[1])
						|| (pair1[0] > pair2[0] && pair1[1] < pair2[1])){
					disconcordantPairs += 1.0;
				}
				// Check if tie in A
				if (Double.compare(pair1[0], pair2[0]) == 0.0){
					tiesA += 1.0;
				}
				// Check if tie in B
				if (Double.compare(pair1[1], pair2[1]) == 0.0){
					tiesB += 1.0;
				}
			}
		}
		// Compute and return kendallsTau
		double pairs = rankPairs.size()*(rankPairs.size()-1)/2.0;
		
		if (TAU.equals("tau-a")){
			double kendallsTauA = (concordantPairs-disconcordantPairs) / pairs;
			return kendallsTauA;
		}
		
		double kendallsTauB = (concordantPairs-disconcordantPairs) / 
				Math.sqrt((pairs-tiesA)*(pairs-tiesB));
		if (pairs-tiesA == 0 || pairs-tiesB == 0){
			return 0;
		}
		return kendallsTauB;
	}
}














