package argumentrelevance.rankingcorrelation;

import java.util.Map;

/**
 * This class computes the Pearson correlations between argument rankings.
 * 
 * @author henning.wachsmuth
 *
 */
public class PearsonCorrelationComputer extends AbstractCorrelationComputer {

	@Override
	public double computeCorrelation(Map<Integer, Double> argumentID2RankA,
			Map<Integer, Double> argumentID2RankB) {
		// Get means
		double meanA = this.computeMean(argumentID2RankA);
		double meanB = this.computeMean(argumentID2RankB);

		// Compute variances and covariance
		double covariance = 0.0;
		double varianceA = 0.0;
		double varianceB = 0.0;		
		for (int argumentID : argumentID2RankA.keySet()) {
			double rankA = argumentID2RankA.get(argumentID);
			double rankB = argumentID2RankB.get(argumentID);		
			covariance += (rankA-meanA) * (rankB-meanB);
			varianceA += Math.pow((rankA-meanA), 2);
			varianceB += Math.pow((rankB-meanB), 2);
		}
		// Return correlation
		return covariance / Math.sqrt(varianceA*varianceB);
	}
	
	/**
	 * Compute the mean of the given rank values.
	 * 
	 * @param argumentID2Rank The rank values
	 * @return The mean
	 */
	private double computeMean(Map<Integer, Double> argumentID2Rank){
		double mean = 0.0;
		for (int argumentID : argumentID2Rank.keySet()) {
			mean += argumentID2Rank.get(argumentID);
		}
		if (argumentID2Rank.size() > 0){
			mean /= argumentID2Rank.size();
		}
		return mean;
	}

}














