package argumentrelevance.storage;

import java.util.List;

/**
 * Storage class for all information of an argument.
 * 
 * @author henning.wachsmuth
 *
 */
public class Argument {

	// -------------------------------------------------------------------------
	// VALUES
	// -------------------------------------------------------------------------

	/**
	 * The global ID of the argument.
	 */
	private int argumentID;
	
	/**
	 * The global ID of the conclusion argument unit.
	 */
	private int conclusionID;
	
	/**
	 * The global IDs of all premise argument units.
	 */
	private List<Integer> premiseIDs;

	
	
	// -------------------------------------------------------------------------
	// INITIALIZATION
	// -------------------------------------------------------------------------

	/**
	 * Sets all values.
	 * 
	 * @param argumentID The argument ID.
	 * @param conclusionID The conclusion ID
	 * @param premiseIDs The premise IDs
	 */
	public Argument(int argumentID, int conclusionID, List<Integer> premiseIDs){
		super();
		this.argumentID = argumentID;
		this.conclusionID = conclusionID;
		this.premiseIDs = premiseIDs;
	}

	
	
	// -------------------------------------------------------------------------
	// GETTERS AND SETTERS
	// -------------------------------------------------------------------------

	/**
	 * Gets the argument ID.
	 * @return The argument ID
	 */
	public int getArgumentID() {
		return argumentID;
	}

	/**
	 * Sets the argument ID.
	 * @param argumentID The argument ID
	 */
	public void setArgumentID(int argumentID) {
		this.argumentID = argumentID;
	}

	/**
	 * Gets the conclusion ID.
	 * @return The conclusion ID
	 */
	public int getConclusionID() {
		return conclusionID;
	}

	/**
	 * Sets the conclusion ID.
	 * @param conclusionID The conclusion ID
	 */
	public void setConclusionID(int conclusionID) {
		this.conclusionID = conclusionID;
	}

	/**
	 * Gets all premise IDs.
	 * @return The premise IDs
	 */
	public List<Integer> getPremiseIDs() {
		return premiseIDs;
	}

	/**
	 * Sets all premise IDs.
	 * @param premiseIDs The premise IDs
	 */
	public void setPremiseIDs(List<Integer> premiseIDs) {
		this.premiseIDs = premiseIDs;
	}
}
















