package argumentrelevance.storage;

import java.util.Map;
import java.util.TreeMap;

/**
 * Storage class for all information of an argument ranking.
 * 
 * @author henning.wachsmuth
 *
 */
public class ArgumentRanking {

	// -------------------------------------------------------------------------
	// VALUES
	// -------------------------------------------------------------------------

	/**
	 * The global ID of the conclusion argument unit for which arguments are
	 * ranked.
	 */
	private int conclusionID;
	
	/**
	 * Mapping from argument IDs to ranks. Should contain one key/value pair
	 * for each argument that refers to the conclusion with the given ID.
	 */
	private TreeMap<Integer, Double> argumentID2Rank;

	
	
	// -------------------------------------------------------------------------
	// INITIALIZATION
	// -------------------------------------------------------------------------

	/**
	 * Sets all values.
	 * 
	 * @param conclusionID The conclusion ID
	 * @param argumentID2Rank The mapping from argument IDs to rank values
	 */
	public ArgumentRanking(int conclusionID,
			TreeMap<Integer, Double> argumentID2Rank) {
		super();
		this.conclusionID = conclusionID;
		this.argumentID2Rank = argumentID2Rank;
	}

	
	
	// -------------------------------------------------------------------------
	// GETTERS AND SETTERS
	// -------------------------------------------------------------------------

	/**
	 * Gets the conclusion ID.
	 * @return The conclusion ID.
	 */
	public int getConclusionID() {
		return conclusionID;
	}

	/**
	 * Sets the conclusion ID.
	 * @param conclusionID The conclusion ID.
	 */
	public void setConclusionID(int conclusionID) {
		this.conclusionID = conclusionID;
	}

	/**
	 * Gets the mapping from argument IDs to ranks
	 * @return The mapping
	 */
	public Map<Integer, Double> getArgumentID2Rank() {
		return argumentID2Rank;
	}

	/**
	 * Sets the mapping from argument IDs to ranks
	 * @param argumentID2Rank The mapping
	 */
	public void setArgumentID2Rank(TreeMap<Integer, Double> argumentID2Rank) {
		this.argumentID2Rank = argumentID2Rank;
	}
}







